import enum
import json
from typing import Dict


class EventType(enum.Enum):
    SUBMITTED = 0
    EXECUTING = 1
    TERMINATED = 5
    OTHER = -1

class WorkflowEvent:
    def __init__(
        self,
        job_name: str,
        job_id: str,
        event_type: EventType,
        timestamp: str,
        log: str,
        retval: int = None
    ):
        self.job_name = job_name
        self.job_id = str(job_id)
        self.type = event_type
        self.timestamp = timestamp
        self.log = log
        self.retval = retval

    def json(self) -> str:
        d = {
            'job_name': self.job_name,
            'type': str(self.type),
            'timestamp': self.timestamp,
            'return_value': self.retval,
            'log': self.log
        }
        return json.dumps(d)

    def __str__(self):
        return f'WorkflowEvent with data {self.json()}'

    def __repr__(self):
        return f'<wf_monitor.WorkflowEvent {self.__dict__}>'
