import pytest
from wf_monitor.wf_event import EventType
from wf_monitor.monitor import WorkflowMonitor, send_event_data, make_amqp_connection

log_path = 'logs/condor.log'
test_monitor = WorkflowMonitor(log_path)


def test_read_log():
    test_strs = [
        'Image size of job updated: 432',
        '432  -  ResidentSetSize of job (KB)',
        '(1) Normal termination (return value 0)',
        '000 (3983.000.000) 08/26 11:06:06 Job submitted from host: '
        '<10.64.1.178:9618?addrs=10.64.1.178-9618&noUDP&sock=4050180_7e37_3>'
    ]
    for s in test_strs:
        assert s in test_monitor.log


def test_read_log_timeout(capsys):
    with pytest.raises(SystemExit) as sys_ex:
        WorkflowMonitor('logs/file-that-does-not-exist.txt', 1)
    assert sys_ex.type == SystemExit
    assert sys_ex.value.code == -1


def test_parse_log():
    test_event_types = [
        EventType.SUBMITTED,
        EventType.EXECUTING,
        EventType.OTHER,
        EventType.TERMINATED,
        EventType.SUBMITTED,
        EventType.EXECUTING,
        EventType.OTHER,
        EventType.TERMINATED
    ]
    for e, e_type in zip(test_monitor.events, test_event_types):
        assert e.type == e_type


def test_parse_log_error():
    with pytest.raises(ValueError) as val_err:
        WorkflowMonitor('logs/test.log')
    assert val_err.type == ValueError


def test_send_event_data(mocker):
    mock_list = [
        'pika.adapters.blocking_connection.BlockingChannel.basic_publish',
        'wf_monitor.monitor.make_amqp_connection',
        'wf_monitor.monitor.send_event_data',
    ]
    [mocker.patch(mock) for mock in mock_list]

    connection = make_amqp_connection('nmtest')

    for event in WorkflowMonitor(log_path).events:
        send_event_data(connection, event)
    assert connection.channel().basic_publish.call_count == 8
